from typing import *
import aiohttp
import datetime
from sqlalchemy import *
from sqlalchemy.orm import relationship, backref
from sqlalchemy.ext.declarative import declared_attr

from ..types import Updatable, oauth_refresh


# noinspection PyAttributeOutsideInit
class Osu(Updatable):
    __tablename__ = "osu"

    @declared_attr
    def user_id(self):
        return Column(Integer, ForeignKey("users.uid"))

    @declared_attr
    def user(self):
        return relationship("User", backref=backref("osu"))

    @declared_attr
    def access_token(self):
        return Column(String, nullable=False)

    @declared_attr
    def refresh_token(self):
        return Column(String, nullable=False)

    @declared_attr
    def expiration_date(self):
        return Column(DateTime, nullable=False)

    @declared_attr
    def osu_id(self):
        return Column(Integer, primary_key=True)

    @declared_attr
    def username(self):
        return Column(String, nullable=False)

    @declared_attr
    def avatar_url(self):
        return Column(String, nullable=False)

    @declared_attr
    def standard_pp(self):
        return Column(Float)

    @declared_attr
    def taiko_pp(self):
        return Column(Float)

    @declared_attr
    def catch_pp(self):
        return Column(Float)

    @declared_attr
    def mania_pp(self):
        return Column(Float)

    async def refresh(self, *, client_id, client_secret, base_url, path):
        j = await oauth_refresh(url="https://osu.ppy.sh/oauth/token",
                                client_id=client_id,
                                client_secret=client_secret,
                                redirect_uri=f"{base_url}{path}",
                                refresh_code=self.refresh_token)
        self.access_token = j["access_token"]
        self.refresh_token = j["refresh_token"]
        self.expiration_date = datetime.datetime.now() + datetime.timedelta(seconds=j["expires_in"])

    async def refresh_if_expired(self, *, client_id, client_secret, base_url, path):
        if datetime.datetime.now() >= self.expiration_date:
            await self.refresh(client_id=client_id, client_secret=client_secret, base_url=base_url, path=path)

    def json(self) -> dict:
        return {
            "osu_id": self.osu_id,
            "username": self.username,
            "avatar_url": self.avatar_url,
            "standard": {
                "pp": self.standard_pp,
            },
            "taiko": {
                "pp": self.taiko_pp,
            },
            "catch": {
                "pp": self.catch_pp,
            },
            "mania": {
                "pp": self.mania_pp,
            },
        }



from typing import *
import royalnet.utils as ru
import royalnet.backpack.tables as rbt
import royalnet.constellation.api as rca
from ..tables import Fiorygi


class ApiFiorygiStar(rca.ApiStar):
    path = "/api/fiorygi/v2"

    parameters = {
        "get": {
            "uid": "The user to get the fiorygi of."
        }
    }

    tags = ["fiorygi"]

    @rca.magic
    async def get(self, data: rca.ApiData) -> ru.JSON:
        """Get fiorygi information about a specific user."""
        user = await rbt.User.find(self.alchemy, data.session, data.int("uid"))
        if user.fiorygi is None:
            return {
                "fiorygi": 0,
                "transactions": [],
                "warning": "No associated fiorygi table"
            }
        fiorygi: Fiorygi = user.fiorygi
        transactions: ru.JSON = sorted(fiorygi.transactions, key=lambda t: -t.id)
        return {
            "fiorygi": fiorygi.fiorygi,
            "transactions": list(map(lambda t: {
                "id": t.id,
                "change": t.change,
                "reason": t.reason,
                "timestamp": t.timestamp.isoformat() if t.timestamp else None
            }, transactions))
        }



# Imports go here!
from .discord_cv import DiscordCvEvent
from .discord_summon import DiscordSummonEvent
from .discord_play import DiscordPlayEvent
from .discord_skip import DiscordSkipEvent
from .discord_queue import DiscordQueueEvent
from .discord_pause import DiscordPauseEvent
from .discord_playable import DiscordPlaymodeEvent
from .discord_lazy_play import DiscordLazyPlayEvent
from .telegram_message import TelegramMessageEvent
from .pong import PongEvent

# Enter the commands of your Pack here!
available_events = [
    DiscordCvEvent,
    DiscordSummonEvent,
    DiscordPlayEvent,
    DiscordSkipEvent,
    DiscordQueueEvent,
    DiscordPauseEvent,
    DiscordPlaymodeEvent,
    DiscordLazyPlayEvent,
    TelegramMessageEvent,
    PongEvent,
]

# Don't change this, it should automatically generate __all__
__all__ = [command.__name__ for command in available_events]



from starlette.responses import *
import royalnet.utils as ru
import royalnet.backpack.tables as rbt
import royalnet.constellation.api as rca


class ApiUserRygListStar(rca.ApiStar):
    path = "/api/user/ryg/list/v1"

    tags = ["user"]

    @rca.magic
    async def get(self, data: rca.ApiData) -> ru.JSON:
        """Get Royalpack information about all user."""
        users: typing.List[rbt.User] = await ru.asyncify(data.session.query(self.alchemy.get(rbt.User)).all)
        return [{
            **user.json(),
            "bio": user.bio.json() if user.bio is not None else None,
            "fiorygi": user.fiorygi.fiorygi if user.fiorygi is not None else None,
            "steam": [steam.json() for steam in user.steam],
            "leagueoflegends": [leagueoflegends.json() for leagueoflegends in user.leagueoflegends],
            "trivia": user.trivia_score.json() if user.trivia_score is not None else None
        } for user in users]



import aiohttp


async def oauth_refresh(*, url, client_id, client_secret, redirect_uri, refresh_code):
    async with aiohttp.ClientSession() as session:
        async with session.post(url, data={
            "client_id": client_id,
            "client_secret": client_secret,
            "code": refresh_code,
            "grant_type": "authorization_code",
            "redirect_uri": redirect_uri
        }) as response:
            j = await response.json()
            return j



from royalnet.commands import *


class EatCommand(Command):
    name: str = "eat"

    description: str = "Mangia qualcosa!"

    syntax: str = "{cibo}"

    _FOODS = {
        "_default": "🍗 Hai mangiato {food}!\n[i]Ma non è successo nulla.[/i]",

        # Sezione nonna
        "tutto": "👵🏻 Hai mangiato {food}. Si vede che hai gradito il pasto!\n[i]Tua nonna ti serve un'altra"
                 " porzione.[/i]",
        "poco": "👵🏻 Hai mangiato davvero {food}! \n[i]Tua nonna è molto arrabbiata e ferita nell'orgoglio."
                " Vergognati![/i]",
        "nonna": "👵🏻 Hai mangiato tua {food}. In qualche modo, continua a cucinarti cibo anche da dentro la"
                 " pancia.\n[i]This can't end well...[/i]",
        "qualcosa di non cucinato dalla nonna": "👵🏻 Hai mangiato {food}!\n[i]Potresti essere appena stato "
                                                "diseredato...[/i]",
        "qualcosa di non preparato dalla nonna": "👵🏻 Hai mangiato {food}!\n[i]Potresti essere appena stato "
                                                 "diseredato...[/i]",

        # Sezione in cui mangi i membri Royal Games
        "balu": "🚹 Hai mangiato {food}.\n[i]Sa di snado.[/i]",
        "evilbalu": "🚹 Hai mangiato {food}.\n[i]Sa di snado.[/i]",
        "balubis": "🚹 Hai mangiato {food}.\n[i]Sa di acqua calda.[/i]",
        "goodbalu": "🚹 Hai mangiato {food}.\n[i]Sa di acqua calda.[/i]",
        "chiara": "🚺 Hai mangiato {food}.\n[i]Sa un po' di biscotto, ma per lo più sa di curcuma e pepe.[/i]",
        "fabio": "🚹 Hai mangiato {food}.\n[i]Sa di gelatina tuttigusti+1.[/i]",
        "proto": "🚹 Hai mangiato {food}.\n[i]Sa di gelatina tuttigusti+1.[/i]",
        "marco": "🚹 Hai mangiato {food}.\n[i]Sa di carlino <.<[/i]",
        "mallllco": "🚹 Hai mangiato {food}.\n[i]Sa di carlino <.<[/i]",
        "max": "🚹 Hai mangiato {food}.\n[i]Sa di merda.[/i]",
        "maxsensei": "🚹 Hai mangiato {food}.\n[i]Sa di merda.[/i]",
        "steffo": "🚹 Hai mangiato {food}.\n[i]Sa di gelato e di Coca-Cola.[/i]",

        # Sezione in cui mangi i professori dei membri Royal Games
        "arrigo": "🖍 Hai mangiato {food}!\n[i]Ti scrive F: V→W sulla parete dello stomaco con i gessetti colorati.[/i]",
        "bonisoli": "🖍 Hai mangiato {food}!\n[i]Ti scrive F: V→W sulla parete dello stomaco con i gessetti colorati.[/i]",
        "montangero": "📝 Hai mangiato la {food}!\n[i]La digerisci in O(n!).[/i]",
        "marongiu": "🔧 Hai mangiato {food}!\n[i]Il tuo apparato digerente viene trasformato in una pipeline.[/i]",
        "mandreoli": "⚠️ Hai mangiato la {food}!\n[c]Error: Segmentation fault (core dumped)[/c]",
        "la rocca": "📊 Hai mangiato {food}!\n[i]Si distribuisce nel tuo intestino come una Normale.[/i]",
        "villani": "🐜 Hai mangiato {food}!\n[i]Crea una rete neurale sfruttando i tuoi neuroni e le tue cellule.[/i]",
        "novellani": "❓Volevi mangiare {food}...\n[i]...ma invece trovi solo Dell'Amico.[/i]",
        
        # Sezione delle supercazzole
        "antani": "❔ Hai mangiato {food}. \n[i]Con tarapia tapioco o scherziamo? No, mi permetta. Noi siamo in 4.\n"
                  "Come se fosse antani anche per lei soltanto in due, oppure in quattro anche scribàcchi confaldina?\n"
                  "Come antifurto, per esempio.[/i]",
        "indice": "☝️ Hai mangiato l'{food}. \n[i]Ecco, lo alzi. Lo vede, lo vede che stuzzica?[/i]",

        # Sezione con piante e animali
        "cactus": "🌵 Hai mangiato un {food}.\n[i]Gli hai tolto le spine prima, vero?[/i]",
        "tango": "🌳 Hai mangiato un {food}, e un albero insieme ad esso.\n[i]Senti le tue ferite curarsi...[/i]",
        "foglia": "🍁 Hai mangiato la {food}.\n[i]A te non la si fa![/i]",
        "pug": "🐶 Hai provato a mangiare un {food}...\n[i]...Ma Mallllco si è precipitato in soccorso e lo ha salvato![/i]",
        "carlino": "🐶 Hai provato a mangiare un {food}...\n[i]...Ma Mallllco si è precipitato in soccorso e lo ha salvato![/i]",
        "gatto": "🐱 Vieni fermato prima di poter compiere questo gesto orribile.\n"
                 "[i]Il {food} verrà pettato da tutti per farlo riavere dal trauma.[/i]",
        "3 porcellini": "🐷 Hai mangiato i {food}.\n[i]La casa di mattoni non è bastata a fermarti![/i]",
        "tre porcellini": "🐷 Hai mangiato i {food}.\n[i]La casa di mattoni non è bastata a fermarti![/i]",
        "insetto": "🐞 Hai mangiato un {food}.\n[i]Dicono che sia il cibo del futuro, però fa un po' schifo.[/i]",
        "ragno": "🕸 Hai mangiato un {food}.\n[i]Ewww![/i]",
        "crab": "🦀 Hai mangiato un {food}. {food} is gone!\n[i]Senti il tuo stomaco ballare.[/i]",
        "granchio": "🦀 Hai mangiato un {food}. {food} is gone!\n[i]Senti il tuo stomaco ballare.[/i]",

        # Sezione con il cibo "normale"
        "zucca": "🎃 Hai mangiato una {food}. Solo che era una lanterna di Halloween.\n[i]Inizi a fare luce al"
                 " buio.[/i]",
        "mela": "🍎 Hai mangiato una Mela, e hai fatto bene perché una mela al giorno toglie il medico di torno!\n"
                "[i]Adesso sei molto più sano.[/i]",
        "lemon": "🍋 Life gave you {food}s, so you ate them!\n[i]Sono un po' bruschi, ma commestibili.[/i]",
        "lemons": "🍋 Life gave you {food}, so you ate them!\n[i]Sono un po' bruschi, ma commestibili.[/i]",
        "mango": "🥭 Hai mangiato un {food}.\n[i]Ti sembra di avere più mana, adesso.[/i]",
        "mango incantato": "🥭 Hai mangiato un {food}.\n[i]Ti sembra di avere più mana, adesso.[/i]",
        "enchanted mango": "🥭 Hai mangiato un {food}.\n[i]Ti sembra di avere più mana, adesso.[/i]",
        "kiwi": "🥝 Hai mangiato un {food}!\n[i]Li uoi qvei k-\n Li vuoi kuei uiw- \n Vabbè, avete capito![/i]",
        "curry": "🔥 BRUCIAAAAAAAAAA! Il {food} era piccantissimo!\n[i]Stai sputando fiamme![/i]",
        "peperoncino": "🔥 BRUCIAAAAAAAAAA! Il {food} era piccantissimo!\n[i]Stai sputando fiamme![/i]",
        "fungo": "🍄 Hai mangiato un {food}.\n[i]Presto riuscirai a salvare Peach![/i]",
        "little salami": "🥓 Mmmh, tasty!\n[i]Cats can have {food} too![/i]",
        "a little salami": "🥓 Mmmh, tasty!\n[i]Cats can have {food} too![/i]",
        "pollo": '🍗 Il {food} che hai appena mangiato proveniva dallo spazio.\n[i]Coccodè?[/i]',
        "pranzo di marco": '🍗 Hai mangiato il {food}.\n[i]Ti senti lactose-free, ma un po\' povero in calcio.[/i]',
        "pranzo di mallllco": '🍗 Hai mangiato il {food}.\n[i]Ti senti lactose-free, ma un po\' povero in calcio.[/i]',
        "gnocchetti": "🥘 Ullà, sono duri 'sti {food}!\n[i]Fai fatica a digerirli.[/i]",
        "spam": "🥫 Hai mangiato {food}. La famosa carne in gelatina, ovviamente!\n[i]A questo proposito, di "
                "sicuro sarai interessato all'acquisto di 1087 scatole di Simmenthal in offerta speciale![/i]",
        "riso": "🍚 Hai mangiato del {food}. Non ci resta che il Pianto! \n[i]Ba dum tsss![/i]",
        "gelato": "🍨 Mangiando del {food}, hai invocato Steffo.\n[i]Cedigli ora il tuo gelato.[/i]",
        "gelato di steffo": "🍨 Hai provato a rubare il {food}...\n[i]...Ma sei arrivato tardi: l'ha già mangiato.[/i]",
        "biscotto": "🍪 Hai mangiato un {food} di contrabbando.\n[i]L'Inquisizione non lo saprà mai![/i]",
        "biscotti": "🍪 Hai mangiato tanti {food} di contrabbando.\n[i]Attento! L'Inquisizione è sulle tue tracce![/i]",
        "crocchette di pollo": "🍗 Hai mangiato {food}!\n[i]Dio porco maledetto, infame, CAPRA, porca Madonna, Dio cane, "
                               "HAI PERSO. UN POMERIGGIO PER C- ooh se è questo dio cane, altro che sfondamento dei cieli "
                               "*roba non capibile*, sfondi tutti dio can li distruggi, non ci rimane più niente.[/i]",

        # Sezione delle bevande
        "acqua": "💧 Hai bevuto un po' d'{food}.\n[i]Ti depura e ti fa fare tanta plin plin![/i}",
        "cochina": "🥫 Hai bevuto una {food}. \n[i]Bella fresca.[/i]",
        "caffè": "☕️ Oh, no! Questo era il {food} della Peppina!\n[i]Ha provato col tritolo, salti in aria col"
                 " {food}.[/i]",
        "caffé": "☕️ Oh, no! Questo era il {food} della Peppina!\n[i]Ha provato col tritolo, salti in aria col"
                 " {food}.[/i]",
        "caffe": "☕️ Oh, no! Questo era il {food} della Peppina!\n[i]Ha provato col tritolo, salti in aria col"
                 " {food}.[/i]",
        "kaffee": "☕️ Ma BUONGIORNISSIMOOO !!!!\n[i]Non si può iniziare la giornata senza un buon {food} !![/i]",
        "kaffè": "☕️ Ma BUONGIORNISSIMOOO !!!!\n[i]Non si può iniziare la giornata senza un buon {food} !![/i]",
        "kaffé": "☕️ Ma BUONGIORNISSIMOOO !!!!\n[i]Non si può iniziare la giornata senza un buon {food} !![/i]",
        "kaffe": "☕️ Ma BUONGIORNISSIMOOO !!!!\n[i]Non si può iniziare la giornata senza un buon {food} !![/i]",
        "birra": "🍺 Hai mangiato {food}.\n[i]Adesso sei un povero barbone alcolizzato.[/i]",
        "martini": "🍸 Hai ordinato un {food}. Agitato, non mescolato.\n[i]Adesso hai licenza di uccidere![/i]",
        "redbull": "🍾 Hai mangiato {food}.\n[i]Adesso puoi volare![/i]",
        "red bull": "🍾 Hai mangiato {food}.\n[i]Adesso puoi volare![/i]",

        # Distribuzioni
        "linux": "🐧 Hai mangiato {food}.\n[i]Senti systemd battere nel tuo cuore, adesso.[/i]",
        "arch": "🐧 Hai mangiato {food}, btw.\n[i]Ti senti più vicino a pacman, adesso.[/i]",
        "arch linux": "🐧 Hai mangiato {food}, btw.\n[i]Ti senti più vicino a pacman, adesso.[/i]",
        "ubuntu": "🐧 Hai mangiato {food}.\n[i]Canonical è fiera di te.[/i]",
        "debian": "🐧 Hai mangiato {food}.\n[i]Hai ancora fame.[/i]",
        "gentoo": "🐧 Hai mangiato {food}.\n[i]Sta ricompilando il tuo stomaco.[/i]",
        "fedora": "🐧 Hai mangiato {food}.\n[i]Se IBM non rovina Fedora mi mangio il cappello.[/i]",
        "red hat": "🐧 Hai mangiato {food}.\n[i]La tua anima appartiene a IBM, ora.[/i]",
        "redhat": "🐧 Hai mangiato {food}.\n[i]La tua anima appartiene a IBM, ora.[/i]",
        "linux from scratch": "🐧 Hai mangiato {food}.\n[i]Sei diventato un puzzle.[/i]",
        
        # Citazioni da film (nello specifico dai Blues Brothers)
        "pane bianco tostato liscio, quattro polli fritti e una coca": "🕶 Tu e tuo fratello avete ordinato {food}."
        " Il cuoco vi ha riconosciuto e vuole tornare a suonare nella vostra band.\n[i]Sua moglie gliene canta"
        " quattro (letteralmente), ma non riesce a fargli cambiare idea. Siete in missione per conto di Dio![/i]",
        "pane bianco tostato liscio": "🕶 Tu e tuo fratello avete ordinato {food}, quattro polli fritti e una coca."
        " Il cuoco vi ha riconosciuto e vuole tornare a suonare nella vostra band.\n[i]Sua moglie gliene canta"
        " quattro (letteralmente), ma non riesce a fargli cambiare idea. Siete in missione per conto di Dio![/i]",
        "quattro polli fritti e una coca": "🕶 Tu e tuo fratello avete ordinato pane bianco tostato liscio, {food}."
        " Il cuoco vi ha riconosciuto e vuole tornare a suonare nella vostra band.\n[i]Sua moglie gliene canta"
        " quattro (letteralmente), ma non riesce a fargli cambiare idea. Siete in missione per conto di Dio![/i]",
        
        # Altro
        "vendetta": "😈 Ti sei gustato la tua {food}.\n[i]Deliziosa, se servita fredda![/i]",
        "demone": "👿 Hai mangiato un {food}. Non l'ha presa bene...\n[i]Hai terribili bruciori di stomaco.[/i]",
        "diavolo": "👿 Hai mangiato un {food}. Non l'ha presa bene...\n[i]Hai terribili bruciori di stomaco.[/i]",
        "cacca": "💩 Che schifo! Hai mangiato {food}!\n[i]Allontati per favore, PLEH![/i]",
        "tonnuooooooro": "👻 Il {food} che hai mangiato era posseduto.\n[i]Spooky![/i]",
        "veleno": "☠️ Hai mangiato del {food}. Perché lo hai fatto?\n[i]Adesso stai male, contento?[/i]",
        "bug": "👾 Bravo, hai mangiato un {food}! Il tuo programma funziona un po' meglio.\n[i]Il problema è che "
               "ne sono comparsi altri tre.[/i]",
        "bot": "🤖 Come osi provare a mangiarmi?!\n[i]Il {food} è arrabbiato con te.[/i]",
        "royal bot": "🤖 Come osi provare a mangiarmi?!\n[i]Il {food} è arrabbiato con te.[/i]",
        "re": "👑 Hai mangiato il {food} avversario! \n[i]Scacco matto![/i]",
        "furry": "🐕 Hai mangiato {food}.\n[i]OwO[/i]",
        "qualcosa che non mi piace": "🥦 Hai assaggiato il cibo, ma non ti piace proprio./n[i]Dai, mangialo, che ti"
        " fa bene! In africa i bambini muoiono di fame, e tu... ![/i]",
        "qualcosa che non ti piace": "🥦 Hai assaggiato il cibo, ma non ti piace proprio./n[i]Dai, mangialo, che ti"
        " fa bene! In africa i bambini muoiono di fame, e tu... ![/i]",
        "polvere": "☁️ Hai mangiato la {food}.\n[i]Ti hanno proprio battuto![/i]",
        "giaroun": "🥌 Il {food} che hai mangiato era duro come un {food}.\n[i]Stai soffrendo di indigestione![/i]",
        "giarone": "🥌 Il {food} che hai mangiato era duro come un {food}.\n[i]Stai soffrendo di indigestione![/i]",
        "sasso": "🥌 Il {food} che hai mangiato era duro come un {food}.\n[i]Stai soffrendo di indigestione![/i]",
        "bomba": "💣 Hai mangiato una {food}. Speriamo fosse solo calorica!\n[i]3... 2... 1...[/i]",
        "ass": "🕳 Hai mangiato {food}.\n[i]Bleah! Lo sai cosa fa quel coso per sopravvivere?[/i]",
        "onion": "🗞 You ate the {food}. Ci sei proprio cascato!\n [i]Hai mai creduto a una notizia di Lercio,"
                 " invece?[/i]",
        "uranio": "☢️ L'{food} che hai mangiato era radioattivo.\n[i]Stai brillando di verde![/i]",
        "tide pod": "☣️ I {food} che hai mangiato erano buonissimi.\n[i]Stai sbiancando![/i]",
        "tide pods": "☣️ I {food} che hai mangiato erano buonissimi.\n[i]Stai sbiancando![/i]",
        "tua mamma": "⚠️ Non sei riuscito a mangiare {food}.\n[i]Era troppo grande e non ci stava nella tua bocca![/i]",
        "troppo": "⚠️ Hai mangiato {food}!\n[i]Hai un terribile mal di pancia.[/i]",
        "musica": "🎶 Hai mangiato un po' di {food} mentre ascoltavi un buon pranzo.\n[i]Tutto ciò ha perfettamente"
                  " senso.[/i]",
        "niente": "⬜️ Non hai mangiato {food}.\n[i]Hai ancora più fame.[/i]",
        "nulla": "⬜️ Non hai mangiato {food}.\n[i]Hai ancora più fame.[/i]",
        "torta": "⬜️ Non hai mangiato niente.\n[i]La {food} è una menzogna![/i]",
        "cake": "⬜️ Non hai mangiato niente.\n[i]The {food} is a lie![/i]",
        "markov": "🗨 Stai cercando di mangiare... un matematico russo di nome {food}?\n[i]Lo trovi un po' indigesto.[/i]",
        "mia sul fiume": "💧 Hai mangiato il miglior piatto al mondo, la {food}, esclusivo ai membri Royal Games.\n"
                         "[i]Nessuno, tranne il bot, sa di cosa è fatta esattamente, ma una cosa è certa: è "
                         "buonissima![/i]",
        "angelo": "👼 Oh mio dio! E' un {food}!\n[i]Ora hai un digramma ad onda blu.[/i]",
        "unicode": "🍗 Hai mangiato {food}!\n๓ค 𝔫𝔬𝔫 [i]è[/i] 𝓼𝓾𝓬𝓬𝓮𝓼𝓼𝓸 𝕟𝕦𝕝𝕝𝕒.",
        "eco": "🏔 Hai mangiato l'{food} eco eco!\n[i]Ma non è successo nulla ulla ulla.[/i]",
        "disinfettante": "🧴Hai mangiato {food}!\n[i]Secondo Trump, ora sei molto più sano.[/i]",

        "terraria": "🌳 Hai provato a mangiare {food}, ma non ne sei stato all'Altezza (Coniglio).\n[i]Prova a mangiare qualcos'altro...[/i]",
        "cooked fish": "🐟 Hai mangiato {food}.\n[i]Ora sei Well Fed per 20 minuti.[/i]",
        "gestione": "🌐 Hai mangiato {food}, su cui si basa Condivisione.\n[i]Fa ridere di sotto, ma fa anche riflettere di sopra.[/i]",
        "condivisione": "🌐 Hai mangiato {food}, basato su Gestione.\n[i]Fa ridere di sopra, ma fa anche riflettere di sotto.[/i]",
    }

    async def run(self, args: CommandArgs, data: CommandData) -> None:
        food = args.joined(require_at_least=1)
        food_string = self._FOODS.get(food.lower(), self._FOODS["_default"])
        await data.reply(food_string.format(food=food.capitalize()))



from typing import *
import telegram
from royalnet.commands import *


class CiaoruoziCommand(Command):
    name: str = "ciaoruozi"

    description: str = "Saluta Ruozi, un leggendario essere che è tornato in Royal Games."

    async def run(self, args: CommandArgs, data: CommandData) -> None:
        if self.interface.name == "telegram":
            user: telegram.User = data.message.from_user
            # Se sei Ruozi, salutati da solo!
            if user.id == 112437036:
                await data.reply("👋 Ciao me!")
                return
        await data.reply("👋 Ciao Ruozi!")



from typing import *
import royalnet
import royalnet.commands as rc
import random
import datetime


class FortuneCommand(rc.Command):
    name: str = "fortune"

    description: str = "Quanto sarai fortunato oggi?"

    syntax: str = ""

    _fortunes = [
        "😄 Oggi sarà una fantastica giornata!",
        "😌 Oggi sarà una giornata molto chill e rilassante.",
        "💰 Oggi sui tuoi alberi cresceranno più Stelline!",
        "🍎 Oggi un unicorno ti lascerà la sua Blessed Apple!",
        "📈 Oggi il tuo team in ranked sarà più amichevole e competente del solito!",
        "🏝 Oggi potrai raggiungere l'Isola Miraggio!",
        "🐱 Oggi vedrai più gatti del solito su Internet!",
        "🐶 Oggi vedrai più cani del solito su Internet!",
        "🐦 Oggi vedrai più uccelli del solito su Internet!",
        "🔥 Oggi vedrai più flame del solito su Internet!",
        "🤬 Oggi vedrai più discorsi politici del solito su Internet!",
        "🐌 Oggi incontrerai una chiocciola sperduta!",
        "🎁 Oggi i dispenser di regali in centro funzioneranno senza problemi!",
        "🥕 Oggi il tuo raccolto avrà qualità Iridium Star!",
        "🔴 Oggi troverai più oggetti di rarità rossa del solito!",
        "✨ Oggi farai molti più multicast!",
        "♦️ Oggi troverai una Leggendaria Dorata!",
        "⭐️ Oggi la stella della RYG ti sembrerà un pochino più dritta!",
        "⭐️ Oggi la stella della RYG ti sembrerà anche più storta del solito!",
        "💎 Oggi i tuoi avversari non riusciranno a deflettere i tuoi Emerald Splash!",
        "⁉️ Oggi le tue supercazzole prematureranno un po' più a sinistra!",
        "🌅 Oggi sarà il giorno dopo ieri e il giorno prima di domani!",
        "🤖 Oggi il Royal Bot ti dirà qualcosa di molto utile!",
        "💤 Oggi rischierai di addormentarti più volte!",
        "🥪 Oggi ti verrà fame fuori orario!",
        "😓 Oggi dirai molte stupidaggini!",
    ]

    async def run(self, args: rc.CommandArgs, data: rc.CommandData) -> None:
        author = await data.get_author()
        today = datetime.date.today()

        h = author.uid * hash(today)

        r = random.Random(x=h)

        message = r.sample(self._fortunes, 1)[0]
        await data.reply(message)



import royalnet.utils as ru
import royalnet.constellation.api as rca
from ..tables import Cvstats


class ApiCvstatsLatestStar(rca.ApiStar):
    path = "/api/cvstats/latest/v1"

    tags = ["cvstats"]

    @rca.magic
    async def get(self, data: rca.ApiData) -> ru.JSON:
        """Get the latest 500 cvstats recorded."""
        CvstatsT = self.alchemy.get(Cvstats)

        cvstats = data.session.query(CvstatsT).order_by(CvstatsT.timestamp.desc()).limit(500).all()

        return list(map(lambda c: c.json(), cvstats))



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['royalpack',
 'royalpack.commands',
 'royalpack.commands.abstract',
 'royalpack.events',
 'royalpack.stars',
 'royalpack.tables',
 'royalpack.types',
 'royalpack.utils']

package_data = \
{'': ['*'], 'royalpack': ['pycharm/*']}

install_requires = \
['bcrypt>=3.1.7,<4.0.0',
 'itsdangerous>=1.1.0,<2.0.0',
 'riotwatcher>=3.0.0,<4.0.0',
 'royalnet[telegram,discord,alchemy_easy,bard,constellation,sentry,herald,coloredlogs]>=5.10.4,<5.11.0',
 'royalspells>=3.2,<4.0',
 'sqlalchemy>=1.3.18,<2.0.0',
 'steam']

setup_kwargs = {
    'name': 'royalpack',
    'version': '5.13.7',
    'description': 'A Royalnet command pack for the Royal Games community',
    'long_description': '# `royalpack`\n\n## Configuration\n\n```toml\n[Packs."royalpack"]\n\n# The main Telegram group\nTelegram.main_group_id = -1001153723135\n\n# The main Discord channel\nDiscord.main_channel_id = 566023556618518538\n\n# A Imgur API token (https://apidocs.imgur.com/?version=latest)\nImgur.token = "1234567890abcde"\n\n# A Steam Web API key (https://steamcommunity.com/dev/apikey)\nSteam.web_api_key = "123567890ABCDEF123567890ABCDEF12"\n\n# The Peertube instance you want to use for new video notifications\nPeertube.instance_url = "https://pt.steffo.eu"\n\n# The delay in seconds between two new video checks\nPeertube.feed_update_timeout = 300\n\n# The Funkwhale instance you want to use for the fw commands\nFunkwhale.instance_url = "https://fw.steffo.eu"\n\n# The id of the role that users should have to be displayed by default in cv\nCv.displayed_role_id = 424549048561958912\n\n# The max duration of a song downloaded with the play commands\nPlay.max_song_duration = 7230\n\n# The Telegram channel where matchmaking messages should be sent in\nMatchmaking.mm_chat_id = -1001204402796\n\n[Packs."royalpack"."steampowered"]\ntoken = "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"\n\n[Packs."royalpack"."steampowered".updater]\nenabled = false\nperiod = 86400\ndelay = 1\ntarget = -1001153723135\n\n[Packs."royalpack"."dota".updater]\nenabled = true\nperiod = 86400\ndelay = 1\ntarget = -1001153723135\n\n[Packs."royalpack"."brawlhalla"]\ntoken = "1234567890ABCDEFGHJKLMNOPQRST"\n\n[Packs."royalpack"."brawlhalla".updater]\nenabled = true\nperiod = 86400\ndelay = 1\ntarget = -1001153723135\n\n[Packs."royalpack"."leagueoflegends"]\ntoken = "RGAPI-AAAAAAAA-AAAA-AAAA-AAAA-AAAAAAAAAAAA"\nregion = "euw1"\n\n[Packs."royalpack"."leagueoflegends".updater]\nenabled = true\nperiod = 86400\ndelay = 1\ntarget = -1001153723135\n\n[Packs."royalpack"."osu"]\nclient_id = 123456789\nclient_secret = "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"\n\n[Packs."royalpack"."osu".login]\nenabled = false\n\n[Packs."royalpack"."osu".updater]\nenabled = true\nperiod = 86400\ndelay = 5\ntarget = -1001153723135\n```',
    'author': 'Stefano Pigozzi',
    'author_email': 'ste.pigozzi@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Steffo99/royalpack',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



# Imports go here!
from .ahnonlosoio import AhnonlosoioCommand
from .answer import AnswerCommand
from .brawlhalla import BrawlhallaCommand
from .cat import CatCommand
from .ciaoruozi import CiaoruoziCommand
from .color import ColorCommand
from .cv import CvCommand
from .cvstats import CvstatsCommand
from .diario import DiarioCommand
from .diarioquote import DiarioquoteCommand
from .diarioshuffle import DiarioshuffleCommand
from .dota import DotaCommand
from .eat import EatCommand
from .emojify import EmojifyCommand
from .eval import EvalCommand
from .exec import ExecCommand
from .fortune import FortuneCommand
from .givefiorygi import GivefiorygiCommand
from .givetreasure import GivetreasureCommand
from .help import HelpCommand
from .leagueoflegends import LeagueoflegendsCommand
from .magickfiorygi import MagickfiorygiCommand
from .magicktreasure import MagicktreasureCommand
from .matchmaking import MatchmakingCommand
from .peertubeupdates import PeertubeUpdatesCommand
from .ping import PingCommand
from .pmots import PmotsCommand
from .dog import DogCommand
from .rage import RageCommand
from .reminder import ReminderCommand
from .royalpackversion import RoyalpackCommand
from .ship import ShipCommand
from .smecds import SmecdsCommand
from .spell import SpellCommand
from .steammatch import SteammatchCommand
from .steampowered import SteampoweredCommand
from .treasure import TreasureCommand
from .trivia import TriviaCommand
from .userinfo import UserinfoCommand
from .osu import OsuCommand

# Enter the commands of your Pack here!
available_commands = [
    AhnonlosoioCommand,
    AnswerCommand,
    BrawlhallaCommand,
    CatCommand,
    CiaoruoziCommand,
    ColorCommand,
    CvCommand,
    CvstatsCommand,
    DiarioCommand,
    DiarioquoteCommand,
    DiarioshuffleCommand,
    DotaCommand,
    EatCommand,
    EmojifyCommand,
    EvalCommand,
    ExecCommand,
    FortuneCommand,
    GivefiorygiCommand,
    GivetreasureCommand,
    HelpCommand,
    LeagueoflegendsCommand,
    MagickfiorygiCommand,
    MagicktreasureCommand,
    MatchmakingCommand,
    PeertubeUpdatesCommand,
    PingCommand,
    PmotsCommand,
    DogCommand,
    RageCommand,
    ReminderCommand,
    RoyalpackCommand,
    ShipCommand,
    SmecdsCommand,
    SpellCommand,
    SteammatchCommand,
    SteampoweredCommand,
    TreasureCommand,
    TriviaCommand,
    UserinfoCommand,
    OsuCommand,
]

# Don't change this, it should automatically generate __all__
__all__ = [command.__name__ for command in available_commands]



from sqlalchemy import *
from sqlalchemy.orm import relationship, backref
from sqlalchemy.ext.declarative import declared_attr
import steam.steamid


class Steam:
    __tablename__ = "steam"

    @declared_attr
    def user_id(self):
        return Column(Integer, ForeignKey("users.uid"))

    @declared_attr
    def user(self):
        return relationship("User", backref=backref("steam"))

    @declared_attr
    def _steamid(self):
        return Column(BigInteger, primary_key=True)

    @property
    def steamid(self):
        return steam.steamid.SteamID(self._steamid)

    @declared_attr
    def persona_name(self):
        return Column(String)

    @declared_attr
    def profile_url(self):
        return Column(String)

    @declared_attr
    def avatar(self):
        return Column(String)

    @declared_attr
    def primary_clan_id(self):
        return Column(BigInteger)

    @declared_attr
    def account_creation_date(self):
        return Column(DateTime)

    @declared_attr
    def account_level(self):
        return Column(Integer, nullable=False, default=0)

    @declared_attr
    def owned_games_count(self):
        return Column(Integer, nullable=False, default=0)

    @declared_attr
    def most_played_game_2weeks(self):
        return Column(Integer, nullable=False, default=753)

    @declared_attr
    def most_played_game_forever(self):
        return Column(Integer, nullable=False, default=753)

    def json(self):
        return {
            "steamid2": self.steamid.as_steam2,
            "steamid3": self.steamid.as_steam3,
            "steamid32": self.steamid.as_32,
            "steamid64": self.steamid.as_64,
            "persona_name": self.persona_name,
            "profile_url": self.profile_url,
            "avatar": self.avatar,
            "primary_clan_id": self.primary_clan_id,
            "account_creation_date": self.account_creation_date.isoformat(),
            "account_level": self.account_level,
            "owned_games_count": self.owned_games_count,
            "most_played_game_2weeks": self.most_played_game_2weeks,
            "most_played_game_forever": self.most_played_game_forever,

            "dota": self.dota.json() if self.dota is not None else None,
            "brawlhalla": self.brawlhalla.json() if self.brawlhalla is not None else None
        }

    def __repr__(self):
        return f"<Steam account {self._steamid} of {self.user}>"

    def __str__(self):
        return f"[c]steam:{self._steamid}[/c]"
